package com.ruoyi.szxc.service.impl;

import com.ruoyi.common.annotation.DataScope;
import com.ruoyi.common.utils.DateUtils;
import com.ruoyi.szxc.domain.SzxcHouseInfo;
import com.ruoyi.szxc.mapper.SzxcHouseInfoMapper;
import com.ruoyi.szxc.service.ISzxcHouseInfoService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.List;

/**
 * 房屋信息Service业务层处理
 *
 * @author hs
 * @date 2024-03-21
 */
@Service
public class SzxcHouseInfoServiceImpl implements ISzxcHouseInfoService
{
    @Autowired
    private SzxcHouseInfoMapper szxcHouseInfoMapper;

    /**
     * 查询房屋信息
     *
     * @param id 房屋信息主键
     * @return 房屋信息
     */
    @Override
    public SzxcHouseInfo selectSzxcHouseInfoById(Long id)
    {
        return szxcHouseInfoMapper.selectSzxcHouseInfoById(id);
    }

    /**
     * 查询房屋信息列表
     *
     * @param szxcHouseInfo 房屋信息
     * @return 房屋信息
     */
    @Override
    @DataScope(deptAlias = "h")
    public List<SzxcHouseInfo> selectSzxcHouseInfoList(SzxcHouseInfo szxcHouseInfo)
    {
        return szxcHouseInfoMapper.selectSzxcHouseInfoList(szxcHouseInfo);
    }

    /**
     * 新增房屋信息
     *
     * @param szxcHouseInfo 房屋信息
     * @return 结果
     */
    @Override
    public int insertSzxcHouseInfo(SzxcHouseInfo szxcHouseInfo)
    {
        szxcHouseInfo.setCreateTime(DateUtils.getNowDate());
        return szxcHouseInfoMapper.insertSzxcHouseInfo(szxcHouseInfo);
    }

    /**
     * 修改房屋信息
     *
     * @param szxcHouseInfo 房屋信息
     * @return 结果
     */
    @Override
    public int updateSzxcHouseInfo(SzxcHouseInfo szxcHouseInfo)
    {
        szxcHouseInfo.setUpdateTime(DateUtils.getNowDate());
        return szxcHouseInfoMapper.updateSzxcHouseInfo(szxcHouseInfo);
    }

    /**
     * 批量删除房屋信息
     *
     * @param ids 需要删除的房屋信息主键
     * @return 结果
     */
    @Override
    public int deleteSzxcHouseInfoByIds(Long[] ids)
    {
        return szxcHouseInfoMapper.deleteSzxcHouseInfoByIds(ids);
    }

    /**
     * 删除房屋信息信息
     *
     * @param id 房屋信息主键
     * @return 结果
     */
    @Override
    public int deleteSzxcHouseInfoById(Long id)
    {
        return szxcHouseInfoMapper.deleteSzxcHouseInfoById(id);
    }
}
